| prob_detectable_curve | R Documentation |
This function takes the model parameters and returns a gamma-distributed curve of the probabilities of detectable viral loads with parameters pars and ages.
prob_detectable_curve(pars, ages)
pars |
Model parameters. |
ages |
Vector of times since infection. |
Returns a gamma-distributed curve of the probabilities of detectable viral loads.
James Hay, jhay@hsph.harvard.edu
Other likelihood functions:
likelihood_R(),
likelihood_cpp_wrapper(),
likelihood_detectable(),
likelihood_pos_R(),
p_a(),
prop_detectable_single(),
prop_detectable()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.