View source: R/simulation_functions.R
| simulate_viral_loads_example | R Documentation |
This function simulates N Ct values per age in ages and returns a dataframe of Ct values and ages.
simulate_viral_loads_example(ages, kinetics_pars, N = 100)
ages |
Vector of ages (days since infection). |
kinetics_pars |
Vector of named parameters for the viral kinetics model. |
N |
Number of observations to randomly generate per age; Set to 100 by default. |
Dataframe of simulated Ct values and corresponding ages.
James Hay, jameshay218@gmail.com
Other viral load functions:
pred_dist_wrapper(),
simulate_detectable_wrapper(),
simulate_viral_loads_example_symptoms(),
viral_load_func()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.