View source: R/incidence_functions.R
| solveSEEIRRModel_rlsoda_wrapper | R Documentation |
This function returns a vector of incidence values for given times according to SEIRR model parameters. It utilizes rlsoda, a solver for ordinary differential equations but is not available on CRAN.
solveSEEIRRModel_rlsoda_wrapper(pars, times)
pars |
Vector of labeled SEEIRR model parameters. |
times |
Time points for incidence calculation. |
Returns incidence values for given points in time.
James Hay, jameshay218@gmail.com
Other incidence functions:
SEEIRRModel(),
detectable_SEEIRRModel(),
detectable_SEIRModel(),
exponential_growth_model(),
gaussian_process_model(),
reverse_gp_model(),
solveSEEIRRModel_rlsoda(),
solveSEIRModel_lsoda_wrapper(),
solveSEIRModel_lsoda(),
solveSEIRModel_rlsoda_wrapper(),
solveSEIRModel_rlsoda(),
solveSEIRswitch_rlsoda_wrapper(),
solveSEIRswitch_rlsoda()
FIX ME
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.